package nl.is.kc.koffiemanager.srv;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.concurrent.locks.ReentrantReadWriteLock;
import java.util.concurrent.locks.ReentrantReadWriteLock.WriteLock;

import javax.enterprise.context.ApplicationScoped;

import nl.is.kc.generiek.domain.Bestelling;
import nl.is.kc.generiek.domain.KoffieDrinker;
import nl.is.kc.generiek.domain.KoffieSoort;

@ApplicationScoped
public class KoffieManager {

	private static final List<KoffieSoort> SOORTEN = Arrays
			.asList(new KoffieSoort("Esspresso", 987L), new KoffieSoort(
					"Koffie", 123L));

	private List<KoffieDrinker> drinkers = new ArrayList<KoffieDrinker>();

	private ReentrantReadWriteLock lock = new ReentrantReadWriteLock();

	private List<Bestelling> bestellingen = new ArrayList<Bestelling>();

	public KoffieManager() {
		super();
	}

	public List<Bestelling> getBestellingen() {
		return Collections.unmodifiableList(bestellingen);
	}

	public void addBestelling(Bestelling bestelling) {
		WriteLock writeLock = lock.writeLock();
		writeLock.lock();
		try {
			bestellingen.add(bestelling);
		} finally {
			writeLock.unlock();
		}
	}

	public void addKoffieDrinker(KoffieDrinker drinker) {
		WriteLock writeLock = lock.writeLock();
		writeLock.lock();
		try {
			drinker.setId(System.currentTimeMillis());
			drinkers.add(drinker);
		} finally {
			writeLock.unlock();
		}
	}

	public List<KoffieDrinker> getKoffieDrinkers() {
		return Collections.unmodifiableList(drinkers);
	}

	public List<KoffieSoort> getKoffieSoorten() {
		return SOORTEN;
	}

	public KoffieDrinker getKoffieDrinkerById(long koffiedrinkerId) {
		for (KoffieDrinker drinker : this.drinkers) {
			if (drinker.getId().equals(koffiedrinkerId)) {
				return drinker;
			}
		}
		return null;

	}

	public KoffieDrinker getKoffieDrinker(String username, String password) {
		for (KoffieDrinker drinker : this.drinkers) {
			if (drinker.getName().getVoornaam().equalsIgnoreCase(username)) {
				return drinker;
			}
		}
		return null;
	}
}
