package nl.is.kc.koffiemanager.ui;

import javax.enterprise.inject.spi.BeanManager;

import net.ftlines.wicket.cdi.CdiConfiguration;
import nl.is.kc.generiek.domain.Name;
import nl.is.kc.koffiemanager.ui.admin.BeheerKoffieApp;
import nl.is.kc.koffiemanager.ui.admin.LoginPage;
import nl.is.kc.koffiemanager.ui.domain.NameConverter;
import nl.is.kc.koffiemanager.ui.muteerdrinkers.AddKoffieDrinkerPage;
import nl.is.kc.koffiemanager.ui.muteerdrinkers.KoffieDrinkerPage;
import nl.is.kc.koffiemanager.ui.raadpleegdrinkers.KoffieDrinkerDetails;

import org.apache.wicket.ConverterLocator;
import org.apache.wicket.IConverterLocator;
import org.apache.wicket.Session;
import org.apache.wicket.authroles.authentication.AbstractAuthenticatedWebSession;
import org.apache.wicket.authroles.authentication.AuthenticatedWebApplication;
import org.apache.wicket.markup.html.WebPage;
import org.apache.wicket.protocol.https.HttpsConfig;
import org.apache.wicket.protocol.https.HttpsMapper;
import org.jboss.weld.environment.servlet.Listener;

/**
 * Application object for your web application. If you want to run this
 * application without deploying, run the Start class.
 * 
 * @see nl.infosupport.kenniscentrum.koffiemanager.Start#main(String[])
 */
public class WicketApplication extends AuthenticatedWebApplication {
	/**
	 * @see org.apache.wicket.Application#getHomePage()
	 */
	@Override
	public Class<HomePage> getHomePage() {
		return HomePage.class;
	}

	@Override
	protected IConverterLocator newConverterLocator() {
		ConverterLocator locator = new ConverterLocator();
		locator.set(Name.class, new NameConverter());
		return locator;
	}

	/**
	 * @see org.apache.wicket.Application#init()
	 */
	@Override
	public void init() {
		super.init();

		BeanManager manager = (BeanManager) getServletContext().getAttribute(
				Listener.BEAN_MANAGER_ATTRIBUTE_NAME);

		new CdiConfiguration(manager).configure(this);

		setRootRequestMapper(new HttpsMapper(getRootRequestMapper(),
				new HttpsConfig(8080, 8181)));

		mountPage("/drinkers/add", AddKoffieDrinkerPage.class);
		mountPage("/drinkers", KoffieDrinkerPage.class);
		mountPage("/drinkers/details", KoffieDrinkerDetails.class);
		mountPage("/admin", BeheerKoffieApp.class);
		mountPage("/login", LoginPage.class);
	}

	public static KoffieManagerSession getSession() {
		return (KoffieManagerSession) Session.get();
	}

	@Override
	protected Class<? extends AbstractAuthenticatedWebSession> getWebSessionClass() {
		return KoffieManagerSession.class;
	}

	@Override
	protected Class<? extends WebPage> getSignInPageClass() {
		return LoginPage.class;
	}
}
